--
-- Very simple addon that adds a note to NPC tooltips when available.
-- If you want to add your own notes in-game, simply do
--  /script MobNotesDB["Name of mob"] = "Note"
-- (note that %t doesn't work with /script)
--
-- Database upgrades (i.e. if the addon is updated on the SVN with new notes)
-- will NOT overwrite or change any custom notes you have added.
--

--[[
<Pkekyo|> much easier to ninja out of combatlog what CAN'T be done imo - for the end user, atleast
<vhaarr> I'm not interested in your opinion
<ag`> :p
<kergoth> write a little addon to ninja those messages and inject them into mobnotes's SV, perhaps.  then it's still flexible for adding any notes, but would gain those bits automatically?
<vhaarr> kergoth: that could be interesting, at least if those "Your Polymorph fails. X is immune." and "Your Wound Poison fails. X is immune." etc messages are generated from the same event.
<vhaarr> kergoth: actually it's CHAT_MSG_SPELL_SELF_DAMAGE
<vhaarr> which is fired pretty often

-- Could still be interesting to fool around with it as a separate addon, but I
-- don't think I want it included here. Perhaps wait for 2.4 and see then.
--
--]]

-- Obviously bump this number if you add any new notes. Note that changing old
-- notes will not upgrade the users DB.
local DB_VERSION = 2

-- The default database should only include strategy-neutral comments, like what
-- mobs are capable of doing and how they can be crowd controlled, or if they
-- are immune to everything, like sheeps or stuns. Don't include any strategy
-- like "kill this mob first" or "have your offtank on this one".
local defaultDatabase = nil

--local l = GetLocale()
-- if l == "enUS" then
defaultDatabase = {
	-- Zul'Aman trash
	["Amani'shi Guardian"] = "Immune to snares, polymorph, and fear. Dispels sheep from nearby friends.",
	["Amani'shi Savage"] = "AoE them down.",
	["Amani'shi Medicine Man"] = "Can be sheeped, snared and MC'ed. Nuke down his totems.",
	["Amani'shi Tribesman"] = "Can be CC'ed by all means.",
	["Amani Bear"] = "Can use Tranquilizing Shot on their frenzy. Freezing Trap, Polymorph and Fear works.",
	["Amani'shi Warbringer"] = "Immune to CC. Dismounts around 20%.",
	["Amani'shi Scout"] = "Can be rooted and stunlocked, prevent them from reaching the drums.",
	["Amani'shi Handler"] = "Immune to Polymorph and Fear, can be stunned. Uses Tranquilizing Poison.",
	["Amani'shi Tempest"] = "Engaging him stops the waves. Does a nasty AoE that can be outranged.",
	["Amani'shi Flame Caster"] = "Vulnerable to Polymorph, Mind Control, snares, stuns and interrupts. Can spell steal his buff.",
	["Amani'shi Beast Tamer"] = "Can be sheeped, trapped and stunned. Mind Controls random players.",

	-- Moroes adds
	["Lady Catriona Von'linda"] = "Holy priest.",
	["Lady Keira Berrybuck"] = "Holy paladin.",
	["Baroness Dorothea Millstipe"] = "Shadow priest with mana burn.",
	["Baron Rafe Drueger"] = "Retribution paladin, will stun.",
	["Lord Robin Daris"] = "Mortal Strike warrior, also does WW.",
	["Lord Crispin Ference"] = "Protection warrior, disarms and shield walls.",

	-- Hex Lord Malacrass adds
	["Thurg"] = "Melee. Can sheep or trap, but he will resist trap a few times.",
	["Gazakroth"] = "Spams fireballs, can be banished.",
	["Lord Raadan"] = "Frontal Flamebreath & Thunderclap, can be sleeped..",
	["Darkheart"] = "Melee and instant cast AoE fear, can be shackled.",
	["Alyson Antille"] = "Heals can be interrupted and she can be sheeped.",
	["Slither"] = "Poison bolts. Can be sleeped.",
	["Fenstalker"] = "Casts Volatile Infection on players, dealing damage to nearby allies. Can be banished.",
	["Koragg"] = "Can be shackled or feared using Turn Undead.",
}
-- elseif l == "deDE" then
--     defaultDatabase = {}
-- end

local prefix = "|cffff4488Note:|r "
local frame = CreateFrame("Frame")
frame:SetScript("OnEvent", function()
	if event == "VARIABLES_LOADED" then
		if not _G.MobNotesDB then
			_G.MobNotesDB = defaultDatabase
			_G.MobNotesDB.VERSION = DB_VERSION
		end

		if not _G.MobNotesDB.VERSION or _G.MobNotesDB.VERSION < DB_VERSION then
			for k, v in pairs(defaultDatabase) do
				if not _G.MobNotesDB[k] then
					_G.MobNotesDB[k] = v
				end
			end
			DEFAULT_CHAT_FRAME:AddMessage("|cffff4488Mob Notes|r database updated to revision " .. tostring(DB_VERSION) .. ".")
			_G.MobNotesDB.VERSION = DB_VERSION
		end

		local orig = GameTooltip:GetScript("OnTooltipSetUnit")
		GameTooltip:SetScript("OnTooltipSetUnit", function(tooltip, ...)
			local name, unitid = tooltip:GetUnit()
			if UnitExists(unitid) and _G.MobNotesDB[name] then
				GameTooltip:AddLine(prefix .. _G.MobNotesDB[name], 0.5, 0.5, 0.5, 1)
			end
			return orig(tooltip, ...)
		end)
	end
end)

frame:RegisterEvent("VARIABLES_LOADED")

